@@ -46,7 +46,7 @@ class SetupAMR(Setup):
         
 
         # for amr
-        self.species_list = ['Acinetobacter_baumannii', "Campylobacter", "Enterococcus_faecalis", "Enterococcus_faecium", "Escherichia", "Klebsiella", "Salmonella", "Staphylococcus_aureus", "Staphylococcus_pseudintermedius", "Streptococcus_agalactiae", "Streptococcus_pneumoniae", "Streptococcus_pyogenes", "Vibrio_cholerae"]
+        self.species_list = ['Acinetobacter_baumannii','Clostridioides_difficile', "Campylobacter", "Enterococcus_faecalis", "Enterococcus_faecium", "Escherichia", "Klebsiella", "Salmonella", "Staphylococcus_aureus", "Staphylococcus_pseudintermedius", "Streptococcus_agalactiae", "Streptococcus_pneumoniae", "Streptococcus_pyogenes", "Vibrio_cholerae"]
         
         self.logger =logging.getLogger(__name__) 
         self.logger.setLevel(logging.INFO)
@@ -176,12 +176,24 @@ class SetupMDU(Setup):
         """
         Check the inputs for MDU - ensure all files are present for collation.
         """
-        self._check_runid()
+        file_dict = {
+            'QC': self.qc, 
+            'summary_matches': self.matches,
+            'summary_partials':self.partials
+            }
 
-        Data = collections.namedtuple('Data', ['qc', 'matches', 'partials', 'db', 'runid', 'sop'])
+        if self._check_runid():
+            self.logger.info(f"You are generating a {'general report' if self.sop == 'general' else 'species specific report'}")
+            self.logger.info(f"Now checking all input files are present.")
+            for _file in file_dict:
+                self.logger.info(f"Checking that {_file} is present.")
+                if self.file_present(file_dict[_file]):
+                    self.logger.info(f"{file_dict[_file]} is present.")
+                else:
+                    self.logger.critical(f"The {_file} file supplied ({file_dict[_file]}) does not exist. Please check your inputs and try again.")
+                    raise SystemExit
 
-        if self.file_present(self.qc) and self.file_present(self.matches) and self._check_runid():
+            Data = collections.namedtuple('Data', ['qc', 'matches', 'partials', 'db', 'runid', 'sop'])
+        
             return Data(self.qc, self.matches, self.partials, self.db, self.runid, self.sop)
-        else:
-            self.logger.critical(f"Something has gone wrong with your inputs. Please try again!")
-            raise SystemExit
+        
\ No newline at end of file
