@@ -11,23 +11,24 @@ abritamr is designed to implement AMRFinder and parse the results compatible for
 """
 
 def run_pipeline(args):
+
     P = SetupAMR(args)
     input_data = P.setup()
-    print(input_data)
     A = RunFinder(input_data)
     amr_data = A.run()
     C = Collate(amr_data)
-    collated_data = C.run()
+    C.run()
     
 
 def mdu(args):
+    
     M = SetupMDU(args)
     input_data = M.setup()
     C = MduCollate(input_data)
-    collated_data = C.run()
+    C.run()
 
 
-def set_parsers():
+def main():
     parser = argparse.ArgumentParser(
         description="AMR gene detection pipeline", formatter_class=argparse.ArgumentDefaultsHelpFormatter
     )
@@ -72,9 +73,9 @@ def set_parsers():
         "-sp",
         default="",
         help="Set if you would like to use point mutations, please provide a valid species.",
-        choices= ['Neisseria', 'Acinetobacter_baumannii', "Campylobacter", "Enterococcus_faecalis", "Enterococcus_faecium", "Escherichia", "Klebsiella", "Salmonella", "Staphylococcus_aureus", "Staphylococcus_pseudintermedius", "Streptococcus_agalactiae", "Streptococcus_pneumoniae", "Streptococcus_pyogenes", "Vibrio_cholerae"]
+        choices= ['Neisseria','Clostridioides_difficile', 'Acinetobacter_baumannii', "Campylobacter", "Enterococcus_faecalis", "Enterococcus_faecium", "Escherichia", "Klebsiella", "Salmonella", "Staphylococcus_aureus", "Staphylococcus_pseudintermedius", "Streptococcus_agalactiae", "Streptococcus_pneumoniae", "Streptococcus_pyogenes"]
     )
-    parser_mdu = subparsers.add_parser('mdu', help='Finalise abritamr results for MDU service', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    parser_mdu = subparsers.add_parser('report', help='Generate report for use at MDU', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     
     parser_mdu.add_argument(
         "--qc",
@@ -112,20 +113,16 @@ def set_parsers():
     parser_sub_run.set_defaults(func=run_pipeline)
     parser_mdu.set_defaults(func = mdu)
     args = parser.parse_args()
-    return args
-
-
-def main():
-    """
-    run pipeline
-    """
-
-    args = set_parsers()
-    if vars(args) == {}:
+    
+    if len(sys.argv) < 2:
         parser.print_help(sys.stderr)
+    elif len(sys.argv) <= 2 and sys.argv[1] == 'run':
+        parser_sub_run.print_help(sys.stderr)
+    elif len(sys.argv) <= 2 and sys.argv[1] == 'report':
+        parser_mdu.print_help(sys.stderr)
     else:
         args.func(args)
-    
-
-if __name__ == "__main__":
+	
+if __name__ == '__main__':
     main()
+
